split

Function split 

pub fn split<'a, K, V, S, SplitType>(
    v: &'a mut HashMap<K, V, S>,
) -> (HashMapA<'a, K, V, S, SplitType>, HashMapB<'a, K, V, S, SplitType>)
where K: Eq + Hash + 'a, S: BuildHasher, V: Splittable<'a, SplitType> + 'a,
Splits a HashMap into two disjoint hashmap references, able to access the split parts of the stored Splittable values independently.